@@ -713,7 +713,7 @@ END
          }
       }
    }
-print "SMTP SERVER = $smtp_server and VERIFIED_EMAIL = $verified_email\n\n";
+print "\nSMTP SERVER = $smtp_server and VERIFIED_EMAIL = $verified_email\n";
    print "\n   ACCESS GNU SOCIAL UI AT:\n\n",
          " https://$public_ip/index.php\n";
    my $thanks=<<'END';
